@@ -1,7 +1,7 @@
 package File::Write::Rotate;
 
-our $DATE = '2015-01-22'; # DATE
-our $VERSION = '0.26'; # VERSION
+our $DATE = '2015-01-23'; # DATE
+our $VERSION = '0.27'; # VERSION
 
 use 5.010001;
 use strict;
@@ -408,13 +408,12 @@ sub compress {
                 next if $cs; # already compressed
                 next if !$self->{period} && !$rs; # not old file
                 next if  $self->{period} && $period eq $latest_period; # not old file
-                push @tocompress, $orig;
+                push @tocompress, File::Spec->catfile( $self->{dir}, $orig );
             }
 
             if (@tocompress) {
-                my $dir = $self->{dir};
                 foreach my $file (@tocompress) {
-                    gzip( $file => File::Spec->catfile( $dir, "$file.gz" ) )
+                    gzip( $file => "$file.gz" )
                         or do { warn "gzip failed: $GzipError\n"; next };
                     unlink $file;
                 }
@@ -450,7 +449,7 @@ File::Write::Rotate - Write to files that archive/rotate themselves
 
 =head1 VERSION
 
-This document describes version 0.26 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2015-01-22.
+This document describes version 0.27 of File::Write::Rotate (from Perl distribution File-Write-Rotate), released on 2015-01-23.
 
 =head1 SYNOPSIS
 
